@@ -1,28 +1,24 @@
 PK.sim <- function()
 {
-  file.menu <- c("One-Compartment PK Model: IV Route", 
-                 "One-Compartment PK Model: Non IV Route",
-                 "Two-Compartment PK Model",
+  OutputFilez() ### reset all output file names when running PK.sim()
+  file.menu <- c("Single-Dose", 
+                 "Multiple-Dose",
                  "Macroconstant Exponential Functions",
                  "Go Back One Upper Level")
-  pick <- menu(file.menu, title = "<< Selection of PK Model >>")
+  pick <- menu(file.menu, title = "<< Selection of Dose Type >>")
   if (pick == 1){
      cat("\n\n")  
-     sone.iv.route()
+     PK.sim.SD()
   }
   else if (pick == 2){
      cat("\n\n")
-     sone.noniv.route()
+     PK.sim.MD()
   }
   else if (pick == 3){
-     cat("\n\n")
-     stwo.all()
-  }      
-  else if (pick == 4){
      cat("\n\n")
      smacro()
   }
-  else if (pick == 5){
+  else if (pick == 4){
      cat("\n\n")
      run()
   }
