@@ -10,9 +10,10 @@ cat("   888        888  Y88b   888    888 888     \n")
 cat("   888        888   Y88b  888    888 Y88b.   \n")
 cat("   888        888    Y88b 888    888   Y888  \n\n")
 cat("-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-o-\n\n")
-cat(" This report was generated using PKfit v1.2.3\n")
+cat(" This report was generated using PKfit v1.2.5\n")
 cat(" on:-",date(),"\n")
 username<-Sys.info()[['user']]
+if(username=="datawalker") username<-"developer - YJL"
 osname_version<-c(paste(Sys.info()[['sysname']],"-",Sys.info()[['version']],"\n",
                   Sys.info()[['release']],",",Sys.info()[['machine']]))
 cat(" R version:",gsub("R version ","",R.Version()[['version.string']],fixed=TRUE),"\n")
@@ -21,5 +22,9 @@ cat(" user id:",username,"\n\n")
 cat(" PKfit is developed by Chun-ying Lee & Yung-jin Lee.\n")
 cat(" contact: Yung-jin Lee <mobilepk at gmail.com> \n\n")
 cat(" PKfit is under license of GPL-2|GPL-3.\n\n")
+cat(" citation:\n")
+cat("  Lee, Chun-ying and Lee, Yung-jin (2015). PKfit: A Data Analysis\n")
+cat("  Tool for Pharmacokinetics. R package version 1.2.5,\n")
+cat("  <URL: http://CRAN.R-project.org/package=PKfit>.\n")
 cat("..................................................\n\n")
 }
\ No newline at end of file
