@@ -1,5 +1,5 @@
 #for one exponential term
-smacro.one.out<-function(PKtime,A,alpha,defun,par1,par2,i,type) 
+smacro.one.out<-function(PKtime,A,alpha,defun,par1,par2,i,type,MD=FALSE) 
 {
   time<-PKtime$time
   defun<- A*exp(-alpha*time)
@@ -10,7 +10,7 @@ smacro.one.out<-function(PKtime,A,alpha,defun,par1,par2,i,type)
   cat(" Model: one-exponential term model          \n") 
   cat(" Error Type:", type,"                       \n\n")
   sim<-matrix(c(A,alpha,par1,par2),2,2)
-  dimnames(sim)<-list(c("A","alpha"),c("Value","Selected"))
+  dimnames(sim)<-list(c("A","alpha"),c("Simulated Values","Input Values"))
   show(sim)
   cat("******************************************\n\n")
   
@@ -19,6 +19,6 @@ smacro.one.out<-function(PKtime,A,alpha,defun,par1,par2,i,type)
   show(PKindex)
   x<-PKindex[,2]
   y<-PKindex[,3]
-  plotting.sim(i,x,y)
+  plotting.sim(i,x,y,MD)
   return(PKindex) 
 }
