@@ -1,5 +1,5 @@
 #for three exponential term
-smacro.three.out<-function(PKtime,A,alpha,B,beta,C,gamma,defun,par1,par2,par3,par4,par5,par6,i,type)      
+smacro.three.out<-function(PKtime,A,alpha,B,beta,C,gamma,defun,par1,par2,par3,par4,par5,par6,i,type,MD=FALSE)      
 {         
   time<-PKtime$time
   defun<- A*exp(-alpha*time)+B*exp(-beta*time)+C*exp(-gamma*time)
@@ -10,7 +10,7 @@ smacro.three.out<-function(PKtime,A,alpha,B,beta,C,gamma,defun,par1,par2,par3,pa
   cat(" Model: three-exponential term model        \n") 
   cat(" Error Type:", type,"                       \n\n")
   sim<-matrix(c(A,alpha,B,beta,C,gamma,par1,par2,par3,par4,par5,par6),6,2)
-  dimnames(sim)<-list(c("A","alpha","B","beta","C","gamma"),c("Value","Selected"))
+  dimnames(sim)<-list(c("A","alpha","B","beta","C","gamma"),c("Simulated Values","Input Values"))
   show(sim)
   cat("*******************************************\n\n")
   PKindex<-data.frame(i,output)
@@ -18,6 +18,6 @@ smacro.three.out<-function(PKtime,A,alpha,B,beta,C,gamma,defun,par1,par2,par3,pa
   show(PKindex)
   x<-PKindex[,2]
   y<-PKindex[,3]
-  plotting.sim(i,x,y)
+  plotting.sim(i,x,y,MD)
   return(PKindex) 
 }
